thesteps = []
step_title = {0: 'Image calibrator', # optional
              1: 'Image continuum',
              2: 'Image line spw 2 (repr.)',
              3: 'Image line spw 1',
              4: 'Image line spw 3',
              5: 'Image line spw 4',
              6: 'Image line spw 5',
              7: 'Image line spw 6',
              8: 'Export FITS images'}

try:
  print 'List of steps to be executed ...', mysteps
  thesteps = mysteps
except:
  print 'global variable mysteps not set.'
if (thesteps==[]):
  thesteps = range(0,len(step_title))
  print 'Executing all steps: ', thesteps

ms1= ['uid___A002_Xb25e1a_X756f.ms.split.cal',
      'uid___A002_Xb32033_X2f53.ms.split.cal',
      'uid___A002_Xb47876_X338f.ms.split.cal',
      'uid___A002_Xb47876_X7afc.ms.split.cal',
      'uid___A002_Xb48b38_X2d6a.ms.split.cal']

thecalibrator = 'J0238+1636'
thetarget = 'Per15'
thephasecenter = 'J2000 03h29m04.490 +031d14m48.6' # use direction if there is no center field, field ID otherwise
themosaicimsize = [420,420]
thecellsize = '0.14arcsec'
theoutframe = 'LSRK'

# Image a calibator (note: the calibration pipeline already images the calibrators)
mystep = 0
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thecalibrator+'-cont-tclean*')

  tclean(vis=ms1,
         imagename=thecalibrator+'-cont-tclean',
         field=thecalibrator,
         spw=['0'],
         threshold='2mJy', 
         robust=0.5,
         imsize=[300, 300], 
         niter=100, 
         specmode='mfs', 
         deconvolver='mtmfs', # use deconvolver='mtmfs' when the aggregate continuum fractional bandwidth is > 10% and there is a reasonably strong signal; 
                              # otherwise use deconvolver='hogbom'
         nterms=2, # nterms must be > 1 when deconvolver='mtmfs' is chosen
         weighting='briggs',
         pbcor=True, 
         cell=thecellsize, 
         chanchunks=-1, 
         gridder='standard', 
         interactive=True,
         uvtaper = ['0.6arcsec','0.6arcsec','0deg'])

  # NOTE: image will be in *.image.tt0
  #       PB will be in *.pb.tt0

  # equivalent clean command:
  # clean(vis=ms1,
  #       imagename=thecalibrator+'.cont',
  #       outlierfile="",
  #       field=thecalibrator,
  #       spw="0",
  #       mode="mfs",
  #       nterms=1,
  #       niter=100,
  #       threshold="2mJy",
  #       psfmode="clark",
  #       imagermode="csclean",
  #       interactive=True,
  #       mask = [],
  #       imsize=[300, 300],
  #       cell=thecellsize,
  #       weighting="briggs",
  #       robust=0.5,
  #       uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
  #       usescratch=False)


# Image continuum of a target source
mystep = 1
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_cont-tclean*')

  tclean(vis=ms1,
         imagename=thetarget+'_cont-tclean',
         field=thetarget,
         phasecenter=thephasecenter,
         spw=['0'],
         threshold='2mJy', 
         robust=0.5,
         imsize=themosaicimsize, 
         niter=100, 
         weighting='briggs',
         pbcor=True, # will create both pbcorrected and uncorrected images 
         cell=thecellsize, 
         specmode='mfs', 
         deconvolver='hogbom', # use deconvolver='mtmfs' with nterms=2 when the aggregate continuum fractional bandwidth is > 10% and there is a reasonably strong signal; 
                               # otherwise use deconvolver='hogbom'
         nterms=1, # nterms must be ==1 when deconvolver='hogbom' is chosen
         chanchunks=-1, 
         gridder='mosaic', 
         uvtaper=['0.6arcsec','0.6arcsec','0deg'],
         interactive=True)

  # equivalent clean command
  #
  # clean(vis=ms1,
  #       imagename=thetarget+'_cont',
  #       outlierfile="",
  #       field=thetarget,
  #       spw="0",
  #       mode="mfs",
  #       nterms=1,
  #       niter=100,
  #       threshold="2mJy",
  #       psfmode="clark",
  #       imagermode="mosaic",
  #       phasecenter=thephasecenter,
  #       interactive=True,
  #       mask = [],
  #       imsize=themosaicimsize,
  #       cell=thecellsize,
  #       weighting="briggs",
  #       robust = 0.5,
  #       uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
  #       usescratch=False)




# Image line 1 of a target source, C18O 2-1 (the repr. line)
mystep = 2
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_C18O-tclean*')

  tclean(vis=ms1,
         imagename=thetarget+'_C18O-tclean',
         field=thetarget,
         phasecenter=thephasecenter,
         restfreq="219.56035GHz", # C18O 2-1 
         spw=['2'],
         threshold='14mJy', 
         imsize=themosaicimsize, 
         cell=thecellsize, 
         niter=1000, 
         width='0.096km/s',
         start='-9.6km/s',
         outframe='LSRK', # only supported outframe in 4.7.0
         nchan=200,
         deconvolver='hogbom', 
         weighting='briggs',
         robust=0.5,
         pbcor=True, 
         specmode='cube', 
         restoringbeam='common',
         chanchunks=-1, 
         gridder='mosaic', 
         uvtaper=['0.6arcsec','0.6arcsec','0deg'],
         interactive=True)

  # clean(vis=ms1,
  #       imagename=thetarget+'_C18O',
  #       outlierfile="",
  #       field=thetarget,
  #       spw="2",
  #       mode="velocity",
  #       width="0.096km/s",
  #       start='-9.6km/s',
  #       nchan=200,
  #       outframe=theoutframe,
  #       veltype="radio",
  #       interpolation="linear",
  #       niter=1000,
  #       gain=0.1,
  #       threshold="14mJy",
  #       psfmode="clark",
  #       imagermode="mosaic",
  #       multiscale=[],
  #       interactive=True,
  #       mask=[],
  #       imsize=themosaicimsize,
  #       cell=thecellsize,
  #       phasecenter=thephasecenter,
  #       restfreq="219.56035GHz", # C18O 2-1
  #       uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
  #       weighting="briggs",
  #       robust=0.5)


# Image spw 1  of a target source, 13CO
mystep = 3
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_13CO-tclean*')

  tclean(vis=ms1,
         imagename=thetarget+'_13CO-tclean',
         field=thetarget,
         phasecenter=thephasecenter,
         restfreq="220.39868GHz", # 13CO 2-1 
         spw=['1'],
         threshold='14mJy', 
         imsize=themosaicimsize, 
         cell=thecellsize, 
         niter=1000, 
         width='0.096km/s',
         start='-9.6km/s',
         outframe='LSRK', # only supported outframe in 4.7.0
         nchan=200,
         deconvolver='hogbom', 
         weighting='briggs',
         robust=0.5,
         pbcor=True, 
         specmode='cube', 
         restoringbeam='common',
         chanchunks=-1, 
         gridder='mosaic', 
         uvtaper=['0.6arcsec','0.6arcsec','0deg'],
         interactive=True)


# Image spw 3 of a target source, SO3Sigma v=0
mystep = 4
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_SO3Sigma-tclean*')

  tclean(vis=ms1,
         imagename=thetarget+'_SO3Sigma-tclean',
         field=thetarget,
         phasecenter=thephasecenter,
         restfreq="219.94944GHz", # SO 3Sigma v=0
         spw=['3'],
         threshold='14mJy', 
         imsize=themosaicimsize, 
         cell=thecellsize, 
         niter=1000, 
         width='0.166391km/s',
         start='-16.6391km/s',
         outframe='LSRK', # only supported outframe in 4.7.0
         nchan=200,
         deconvolver='hogbom', 
         weighting='briggs',
         robust=0.5,
         pbcor=True, 
         specmode='cube', 
         restoringbeam='common',
         chanchunks=-1, 
         gridder='mosaic', 
         uvtaper=['0.6arcsec','0.6arcsec','0deg'],
         interactive=True)



# Image spw 4 of a target source, H2CO
mystep = 5
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_H2CO-tclean*')

  tclean(vis=ms1,
         imagename=thetarget+'_H2CO-tclean',
         field=thetarget,
         phasecenter=thephasecenter,
         restfreq="218.22219GHz", # H2CO 3(0,3) - 2(0,2)
         spw=['4'],
         threshold='14mJy', 
         imsize=themosaicimsize, 
         cell=thecellsize, 
         niter=1000, 
         width='0.167708km/s',
         start='-16.7708km/s',
         outframe='LSRK', # only supported outframe in 4.7.0
         nchan=200,
         deconvolver='hogbom', 
         weighting='briggs',
         robust=0.5,
         pbcor=True, 
         specmode='cube', 
         restoringbeam='common',
         chanchunks=-1, 
         gridder='mosaic', 
         uvtaper=['0.6arcsec','0.6arcsec','0deg'],
         interactive=True)

# Image spw 5 of a target source, N2D+
mystep = 6
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_N2D+-tclean*')

  tclean(vis=ms1,
         imagename=thetarget+'_N2D+-tclean',
         field=thetarget,
         phasecenter=thephasecenter,
         restfreq="231.32183GHz", # N2D+ 3-2
         spw=['5'],
         threshold='14mJy', 
         imsize=themosaicimsize, 
         cell=thecellsize, 
         niter=1000, 
         width='0.096km/s',
         start='-9.6km/s',
         outframe='LSRK', # only supported outframe in 4.7.0
         nchan=200,
         deconvolver='hogbom', 
         weighting='briggs',
         robust=0.5,
         pbcor=True, 
         specmode='cube', 
         restoringbeam='common',
         chanchunks=-1, 
         gridder='mosaic', 
         uvtaper=['0.6arcsec','0.6arcsec','0deg'],
         interactive=True)



# Image spw 6 of a target source, CO v=0 2-1 
mystep = 7
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_CO-tclean*')

  tclean(vis=ms1,
         imagename=thetarget+'_CO-tclean',
         field=thetarget,
         phasecenter=thephasecenter,
         restfreq="230.53800GHz", # CO v=0 2-1
         spw=['6'],
         threshold='14mJy', 
         imsize=themosaicimsize, 
         cell=thecellsize, 
         niter=1000, 
         width='0.096km/s',
         start='-9.6km/s',
         outframe='LSRK', # only supported outframe in 4.7.0
         nchan=200,
         deconvolver='hogbom', 
         weighting='briggs',
         robust=0.5,
         pbcor=True, 
         specmode='cube', 
         restoringbeam='common',
         chanchunks=-1, 
         gridder='mosaic', 
         uvtaper=['0.6arcsec','0.6arcsec','0deg'],
         interactive=True)

mystep = 8
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  myimages = set([])

  myimages.add(thetarget+'_cont-tclean')
  myimages.add(thetarget+'_C18O-tclean')
  myimages.add(thetarget+'_13CO-tclean')
  myimages.add(thetarget+'_SO3Sigma-tclean')
  myimages.add(thetarget+'_H2CO-tclean')
  myimages.add(thetarget+'_CO-tclean')
  myimages.add(thetarget+'_N2D+-tclean')

  for myimagebase in myimages:
    exportfits(imagename=myimagebase+'.image.pbcor', fitsimage=myimagebase+'.image.pbcor.fits', overwrite=True) # export the corrected image
    exportfits(imagename=myimagebase+'.pb', fitsimage=myimagebase+'.flux.fits', overwrite=True) # export the PB image

