thesteps = []
step_title = {0: 'Image calibrator', # optional
              1: 'Image continuum',
              2: 'Image line spw 2 (repr.)',
              3: 'Image line spw 1',
              4: 'Image line spw 3',
              5: 'Image line spw 4',
              6: 'Image line spw 5',
              7: 'Image line spw 6',
              8: 'Export FITS images'}

try:
  print 'List of steps to be executed ...', mysteps
  thesteps = mysteps
except:
  print 'global variable mysteps not set.'
if (thesteps==[]):
  thesteps = range(0,len(step_title))
  print 'Executing all steps: ', thesteps

ms1= ['uid___A002_Xb25e1a_X756f.ms.split.cal',
      'uid___A002_Xb32033_X2f53.ms.split.cal',
      'uid___A002_Xb47876_X338f.ms.split.cal',
      'uid___A002_Xb47876_X7afc.ms.split.cal',
      'uid___A002_Xb48b38_X2d6a.ms.split.cal']

thecalibrator = 'J0238+1636'
thetarget = 'Per15'
thephasecenter = 'J2000 03h29m04.490 +031d14m48.6' # use direction if there is no center field, field ID otherwise
themosaicimsize = [420,420]
thecellsize = '0.14arcsec'
theoutframe = 'LSRK'

myimages = set([])

# Image a calibator
mystep = 0
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thecalibrator+'.cont*')

  clean(vis=ms1,
        imagename=thecalibrator+'.cont',
        outlierfile="",
        field=thecalibrator,
        spw="0",
        mode="mfs",
        nterms=1,
        niter=100,
        threshold="2mJy",
        psfmode="clark",
        imagermode="csclean",
        interactive=True,
        mask = [],
        imsize=[300, 300],
        cell=thecellsize,
        weighting="briggs",
        robust=0.5,
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        usescratch=False)


# Image continuum of a target source
mystep = 1
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_cont*')

  clean(vis=ms1,
        imagename=thetarget+'_cont',
        outlierfile="",
        field=thetarget,
        spw="0",
        mode="mfs",
        nterms=1,
        niter=100,
        threshold="2mJy",
        psfmode="clark",
        imagermode="mosaic",
        phasecenter=thephasecenter,
        interactive=True,
        mask = [],
        imsize=themosaicimsize,
        cell=thecellsize,
        weighting="briggs",
        robust = 0.5,
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        usescratch=False)




# Image line 1 of a target source, C18O 2-1 (the repr. line)
mystep = 2
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_C180*')

  clean(vis=ms1,
        imagename=thetarget+'_C180',
        outlierfile="",
        field=thetarget,
        spw="2",
        mode="velocity",
        width="0.096km/s",
        start='-9.6km/s',
        nchan=200,
        outframe=theoutframe,
        veltype="radio",
        interpolation="linear",
        niter=0,
        gain=0.1,
        threshold="14mJy",
        psfmode="clark",
        imagermode="mosaic",
        multiscale=[],
        interactive=True,
        mask=[],
        imsize=themosaicimsize,
        cell=thecellsize,
        phasecenter=thephasecenter,
        restfreq="219.56035GHz", # C18O 2-1
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        weighting="briggs",
        robust=0.5)


# Image spw 1  of a target source, 13CO
mystep = 3
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_13CO*')

  clean(vis=ms1,
        imagename=thetarget+'_13CO',
        outlierfile="",
        field=thetarget,
        spw="1",
        mode="velocity",
        width="0.096km/s",
        start='-9.6km/s',
        nchan=200,
        outframe=theoutframe,
        veltype="radio",
        interpolation="linear",
        niter=0,
        gain=0.1,
        threshold="14mJy",
        psfmode="clark",
        imagermode="mosaic",
        multiscale=[],
        interactive=True,
        mask=[],
        imsize=themosaicimsize,
        cell=thecellsize,
        phasecenter=thephasecenter,
        restfreq="220.39868GHz", # 13CO 2-1
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        weighting="briggs",
        robust=0.5)

# Image spw 3 of a target source, SO3Sigma v=0
mystep = 4
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_SO3Sigma*')

  clean(vis=ms1,
        imagename=thetarget+'_SO3Sigma',
        outlierfile="",
        field=thetarget,
        spw="3",
        mode="velocity",
        width="0.166378km/s",
        start='-16.6378km/s',
        nchan=200,
        outframe=theoutframe,
        veltype="radio",
        interpolation="linear",
        niter=0,
        gain=0.1,
        threshold="14mJy",
        psfmode="clark",
        imagermode="mosaic",
        multiscale=[],
        interactive=True,
        mask=[],
        imsize=themosaicimsize,
        cell=thecellsize,
        phasecenter=thephasecenter,
        restfreq="219.94944GHz", # SO 3Sigma v=0
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        weighting="briggs",
        robust=0.5)

# Image spw 4 of a target source, H2CO
mystep = 5
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_H2CO*')

  clean(vis=ms1,
        imagename=thetarget+'_H2CO',
        outlierfile="",
        field=thetarget,
        spw="4",
        mode="velocity",
        width="0.167695km/s",
        start='-16.7695km/s',
        nchan=200,
        outframe=theoutframe,
        veltype="radio",
        interpolation="linear",
        niter=0,
        gain=0.1,
        threshold="14mJy",
        psfmode="clark",
        imagermode="mosaic",
        multiscale=[],
        interactive=True,
        mask=[],
        imsize=themosaicimsize,
        cell=thecellsize,
        phasecenter=thephasecenter,
        restfreq="218.22219GHz", # H2CO 3(0,3) - 2(0,2)
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        weighting="briggs",
        robust=0.5)

# Image spw 5 of a target source, N2D+
mystep = 6
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_N2D+*')

  clean(vis=ms1,
        imagename=thetarget+'_N2D+',
        outlierfile="",
        field=thetarget,
        spw="5",
        mode="velocity",
        width="0.096km/s",
        start='-9.6km/s',
        nchan=200,
        outframe=theoutframe,
        veltype="radio",
        interpolation="linear",
        niter=0,
        gain=0.1,
        threshold="14mJy",
        psfmode="clark",
        imagermode="mosaic",
        multiscale=[],
        interactive=True,
        mask=[],
        imsize=themosaicimsize,
        cell=thecellsize,
        phasecenter=thephasecenter,
        restfreq="231.32183GHz", # N2D+ 3-2
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        weighting="briggs",
        robust=0.5)


# Image spw 6 of a target source, CO v=0 2-1 
mystep = 7
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+thetarget+'_CO*')

  clean(vis=ms1,
        imagename=thetarget+'_CO',
        outlierfile="",
        field=thetarget,
        spw="6",
        mode="velocity",
        width="0.096km/s",
        start='-9.6km/s',
        nchan=200,
        outframe=theoutframe,
        veltype="radio",
        interpolation="linear",
        niter=0,
        gain=0.1,
        threshold="14mJy",
        psfmode="clark",
        imagermode="mosaic",
        multiscale=[],
        interactive=True,
        mask=[],
        imsize=themosaicimsize,
        cell=thecellsize,
        phasecenter=thephasecenter,
        restfreq="230.53800GHz", # CO v=0 2-1
        uvtaper=True, outertaper = ['0.6arcsec','0.6arcsec','0deg'],
        weighting="briggs",
        robust=0.5)




mystep = 8
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  myimages.add(thetarget+'_cont')
  myimages.add(thetarget+'_C18O')
  myimages.add(thetarget+'_13CO')
  myimages.add(thetarget+'_SO3Sigma')
  myimages.add(thetarget+'_H2CO')
  myimages.add(thetarget+'_CO')
  myimages.add(thetarget+'_N2D+')


  for myimagebase in myimages:
    impbcor(imagename=myimagebase+'.image', pbimage=myimagebase+'.flux', outfile=myimagebase+'.image.pbcor', overwrite=True) # perform PBcorr
    exportfits(imagename=myimagebase+'.image.pbcor', fitsimage=myimagebase+'.image.pbcor.fits') # export the corrected image
    exportfits(imagename=myimagebase+'.flux', fitsimage=myimagebase+'.flux.fits') # export the PB image
