# You should run this with CASA 4.6 

thesteps = []
step_title = {0: 'Image continuum of bandpass',
              1: 'Image continuum',
              2: 'Image line spw 0',
              3: 'Image line spw 1',
              4: 'Image line spw 2',
              5: 'Image line spw 3',
              6: 'Export FITS images'}

try:
  print 'List of steps to be executed ...', mysteps
  thesteps = mysteps
except:
  print 'global variable mysteps not set.'
if (thesteps==[]):
  thesteps = range(0,len(step_title))
  print 'Executing all steps: ', thesteps

thems = 'uid___A002_Xb5e334_X2ed1.ms.split.cal'

print thems

# rest freqs for the four SPWs redshifted to 0.017996
v0 = '113.23345GHz' # CO 1-0 
v1 = '111.51363GHz' # CN 1-0 Cyanide Radical N= 1- 0, J=3/2-1/2, F=1/2-3/2 
v2 = '101.54725GHz' # SPW center
v3 = '99.74642GHz' # SPW center

# target names
bpassname = 'J1924-2914'
targetname = 'IRAS_18293-3413'
targetfield = "5"

# image parameters
myimsize = [512, 512]
mycell = "0.165arcsec"
myframe = 'BARY'

myimages = set([])


# Image continuum of the bandpass calibrator
mystep = 0
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+bpassname+'_'+thems+'.cont.*')
  clean(vis=thems,
        imagename=bpassname+'_'+thems+'.cont',
        field="0",
        spw="0~3",
        mode="mfs",
        nterms=2,
        niter=100,
        threshold="1mJy",
        psfmode="clark",
        interactive=True,
        mask = [],
        imsize=myimsize,
        cell=mycell,
        outframe=myframe,
        weighting="briggs",
        robust = 0.5, 
        usescratch=False)

  os.system('mv '+bpassname+'_'+thems+'.cont.image.tt0 '+bpassname+'_'+thems+'.cont.image') 


# Image continuum of the target source
mystep = 1
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+targetname+'_'+thems+'.cont.*')
  clean(vis=thems,
        imagename=targetname+'_'+thems+'.cont',
        field=targetfield,
        spw="0:0~1500;2200~3839,1:800~3500,2:300~1200;1800~3700,3",
        mode="mfs",
        nterms=2,
        niter=100,
        threshold="0.1mJy",
        psfmode="clark",
        interactive=True,
        mask = [],
        imsize=myimsize,
        cell=mycell,
        outframe=myframe,
        weighting="briggs",
        robust = 0.5, 
        usescratch=False)

  os.system('mv '+targetname+'_'+thems+'.cont.image.tt0 '+targetname+'_'+thems+'.cont.image') 

# Image line of the target source, CO, repr. SPW
mystep = 2
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+targetname+'_'+thems+'.CO*')
  clean(vis=thems,
        imagename=targetname+'_'+thems+'.CO',
        field=targetfield,
        spw="0",
        mode="velocity",
        width='15km/s',
        start='-1500km/s',
        nchan=200,
        interpolation="linear",
        threshold="3mJy",
        interactive=True,
        mask=[],
        imsize=myimsize,
        cell=mycell,
        outframe=myframe,
        restfreq=v0,
        weighting="briggs",
        robust=0.)

# Image line of the target source, CN
mystep = 3
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+targetname+'_'+thems+'.CN*')
  clean(vis=thems,
        imagename=targetname+'_'+thems+'.CN',
        field=targetfield,
        spw="1",
        mode="velocity",
        width='15km/s',
        start='-1500km/s',
        nchan=200,
        interpolation="linear",
        threshold="3mJy",
        interactive=True,
        mask=[],
        imsize=myimsize,
        cell=mycell,
        outframe=myframe,
        restfreq=v1,
        weighting="briggs",
        robust=0.)

# Image line of the target source, SPW2
mystep = 4
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+targetname+'_'+thems+'.SPW2*')
  clean(vis=thems,
        imagename=targetname+'_'+thems+'.SPW2',
        field=targetfield,
        spw="2",
        mode="velocity",
        width='15km/s',
        start='-1500km/s',
        nchan=200,
        interpolation="linear",
        threshold="3mJy",
        interactive=True,
        mask=[],
        imsize=myimsize,
        cell=mycell,
        outframe=myframe,
        restfreq=v2,
        weighting="briggs",
        robust=0.)

# Image line of the target source, SPW3
mystep = 5
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf '+targetname+'_'+thems+'.SPW3*')
  clean(vis=thems,
        imagename=targetname+'_'+thems+'.SPW3',
        field=targetfield,
        spw="3",
        mode="velocity",
        width='15km/s',
        start='-1500km/s',
        nchan=200,
        interpolation="linear",
        threshold="3mJy",
        interactive=True,
        mask=[],
        imsize=myimsize,
        cell=mycell,
        outframe=myframe,
        restfreq=v3,
        weighting="briggs",
        robust=0.)


# export fits
mystep = 6
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  myimages.add(targetname+'_'+thems+'.cont')
  myimages.add(targetname+'_'+thems+'.CO')
  myimages.add(targetname+'_'+thems+'.CN')
  myimages.add(targetname+'_'+thems+'.SPW2')
  myimages.add(targetname+'_'+thems+'.SPW3')
  
  for myimagebase in myimages:
    impbcor(imagename=myimagebase+'.image', pbimage=myimagebase+'.flux', outfile=myimagebase+'.image.pbcor', overwrite=True) # perform PBcorr
    exportfits(imagename=myimagebase+'.image.pbcor', fitsimage=myimagebase+'.image.pbcor.fits') # export the corrected image
    exportfits(imagename=myimagebase+'.flux', fitsimage=myimagebase+'.flux.fits') # export the PB image
